@@ -233,3 +233,31 @@ def test_except_formatting():
         'WHERE 1 = 2'
     ])
     assert formatted == tformatted
+
+
+def test_null_with_as():
+    sql = 'SELECT NULL AS c1, NULL AS c2 FROM t1'
+    formatted = sqlparse.format(sql, reindent=True)
+    tformatted = '\n'.join([
+        'SELECT NULL AS c1,',
+        '       NULL AS c2',
+        'FROM t1'
+    ])
+    assert formatted == tformatted
+
+
+def test_issue193_splitting_function():
+    sql = """CREATE FUNCTION a(x VARCHAR(20)) RETURNS VARCHAR(20)
+BEGIN
+ DECLARE y VARCHAR(20);
+ RETURN x;
+END;
+SELECT * FROM a.b;"""
+    splitted = sqlparse.split(sql)
+    assert len(splitted) == 2
+
+
+def test_issue186_get_type():
+    sql = "-- comment\ninsert into foo"
+    p = sqlparse.parse(sql)[0]
+    assert p.get_type() == 'INSERT'
